Backends MAY contain hard ceilings as to the number of them that can be active at any given moment. This hard ceiling is only imposed in circumstances where a dynamic number of instances is impossible to accommodate or because reaching the limit would exhaust system resources. When a backend limit is reached, `prism_backend_initialize` SHALL return `PRISM_ERROR_INTERNAL_BACKEND_LIMIT_EXCEEDED`, and consumers of the Prism library MUST NOT attempt re-initialization of the backend.

At the time of writing, all backend limits are sufficiently high that they are unlikely to be reached under normal usage. As such, no API function exists to query a backend's limit. Consumers SHOULD still handle `PRISM_ERROR_INTERNAL_BACKEND_LIMIT_EXCEEDED` gracefully, but are not expected to design around it.